<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 11/11/19
 * Time: 15.24
 */

namespace FiloBlu\Rma\Model;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Rma\Model\Rma;
use Magento\Store\Model\ScopeInterface;
use FiloBlu\Rma\Model\Rma\Status\HistoryFactory;
use Psr\Log\LoggerInterface;


class RmaEmailManagment
{
    const XML_PATH_STATE_PREFIX = 'sales_email/magento_rma';

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var HistoryFactory
     */
    protected $historyFactory;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * RmaEmailManagment constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param HistoryFactory $historyFactory
     * @param LoggerInterface $logger
     */
    public function __construct(ScopeConfigInterface $scopeConfig,
                                HistoryFactory $historyFactory,
                                LoggerInterface $logger){
        $this->scopeConfig = $scopeConfig;
        $this->historyFactory = $historyFactory;
        $this->logger = $logger;
    }


    /**
     * @param $rmaEntityId
     * @param $status
     * @return Rma\Status\History
     */
    public function sendRmaEmail($rmaEntityId,$status){
        try {
            $path = self::XML_PATH_STATE_PREFIX . "_$status";
            if($status == "authorized"){
                $path = self::XML_PATH_STATE_PREFIX . "_auth";
            }

            if($status == 'pending'){
                $path = self::XML_PATH_STATE_PREFIX ;
            }

            $statusHistory = $this->historyFactory->create();
            $statusHistory->setRmaEntityId($rmaEntityId);
            return $statusHistory->sendRmaEmail($path);

        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
        }
    }


    /**
     * @param Rma $rma
     * @return Rma\Status\History
     */
    public function checkIfSendRmaEmail(Rma $rma){
        $storeId = $rma->getStoreId();
        //get fresh status
        $status = $rma->getStatus();
        if($status == 'pending'){
            $sendEmail = false ; //$this->scopeConfig->getValue(self::XML_PATH_STATE_PREFIX."/enabled",ScopeInterface::SCOPE_STORE,$storeId) ?? false;
        }else{
            $suffix= $status;
            if($status == "authorized"){
                $suffix = "auth";
            }
            $path = self::XML_PATH_STATE_PREFIX."_$suffix/enabled";
            $sendEmail = $this->scopeConfig->getValue($path,ScopeInterface::SCOPE_STORE,$storeId) ?? false;
        }
        if($sendEmail){
           return $this->sendRmaEmail($rma->getEntityId(),$status);
        }
    }

}